@@ -6,7 +6,7 @@ from ev3dev2.port import LegoPort
 import requests
 import json
 
-def ev3():
+def ev3(api_key):
     if (LegoPort('in1').status == 'no-sensor'):
         input_port_1_driver_name = ''
         input_port_1_value = ''
